pub type AllPalletsWithSystem = (System, PalletWithCustomOrigin);Expand description
All pallets included in the runtime as a nested tuple of types.
pub type AllPalletsWithSystem = (System, PalletWithCustomOrigin);All pallets included in the runtime as a nested tuple of types.